<?php

namespace YooMoney\Helpers;

use Psr\Log\LoggerInterface;
use Psr\Log\LogLevel;

/**
 * Класс методов для работы с логами модуля
 */
class LoggerHelper implements LoggerInterface
{
    /**
     * Выполняет подготовку данных и запись лога в файл
     *
     * @param $level
     * @param $message
     * @param array $context
     */
    public function log($level, $message, array $context = array())
    {
        $replace = $this->prepareContext($context);

        $message = strip_tags($message);

        if (!empty($replace)) {
            $message = $this->prepareMessage($replace, $message);
        }

        $this->write($this->getLogFileName(), ' [' . $level . '] ' . $message);
    }

    /**
     * Возвращает путь к файлу лога
     *
     * @return string
     */
    public function getLogFileName()
    {
        return realpath(JSH_DIR).'/log/pm_yoomoney.log';
    }

    /**
     * Подготовка данных из контекста сообщения
     *
     * @param array $context
     * @return array|void
     */
    private function prepareContext($context)
    {
        if (!$context) {
            return;
        }

        $replace = array();
        foreach ($context as $key => $value) {
            $replace['{'.$key.'}'] = (is_array($value) || is_object($value)) ? json_encode($value, JSON_PRETTY_PRINT) : $value;
        }

        return $replace;
    }

    /**
     * Разбивка данных и формирование сообщения
     *
     * @param array $replace
     * @param string $message
     * @return string
     */
    private function prepareMessage($replace, $message)
    {
        foreach ($replace as $key => $object) {
            $label = trim($key, "{}");
            $message .= " \n{$label}: {$object}";
        }

        return $message;
    }

    /**
     * Открытие файла для записи, запись и закрытие файла
     *
     * @param string $fileName
     * @param string $message
     * @return void
     */
    private function write($fileName, $message)
    {
        $fd = @fopen($fileName, 'a');

        if ($fd) {
            flock($fd, LOCK_EX);
            fwrite($fd, date(DATE_ATOM). $message ."\r\n");
            flock($fd, LOCK_UN);
            fclose($fd);
        }
    }

    public function emergency($message, array $context = array())
    {
        $this->log(LogLevel::EMERGENCY, $message, $context);
    }

    public function alert($message, array $context = array())
    {
        $this->log(LogLevel::ALERT, $message, $context);
    }

    public function critical($message, array $context = array())
    {
        $this->log(LogLevel::CRITICAL, $message, $context);
    }

    public function error($message, array $context = array())
    {
        $this->log(LogLevel::ERROR, $message, $context);
    }

    public function warning($message, array $context = array())
    {
        $this->log(LogLevel::WARNING, $message, $context);
    }

    public function notice($message, array $context = array())
    {
        $this->log(LogLevel::NOTICE, $message, $context);
    }

    public function info($message, array $context = array())
    {
        $this->log(LogLevel::INFO, $message, $context);
    }

    public function debug($message, array $context = array())
    {
        $this->log(LogLevel::DEBUG, $message, $context);
    }
}